pub struct Accept {
pub round: Pubkey,
pub heir: Pubkey,
pub offer_wallet: Pubkey,
pub bid_wallet: Pubkey,
pub recipient: Pubkey,
pub authority: Pubkey,
pub payer: Pubkey,
pub token_program: Pubkey,
pub system_program: Pubkey,
}Expand description
Generated client accounts for Accept.
Fields
round: Pubkeyheir: Pubkeyoffer_wallet: Pubkeybid_wallet: Pubkeyrecipient: Pubkeypayer: Pubkeytoken_program: Pubkeysystem_program: PubkeyTrait Implementations
sourceimpl ToAccountMetas for Accept
impl ToAccountMetas for Accept
sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl RefUnwindSafe for Accept
impl Send for Accept
impl Sync for Accept
impl Unpin for Accept
impl UnwindSafe for Accept